==> client-sdk-react-1.0.0.tgz: package/src/components/Chat/ChatMessage/ChatMessageWithParticipantInfo.tsx <==
import React from 'react'
import classNames from 'classnames'
import Linkify from 'linkify-react'
import { ChatMessageElementProps } from '../models'
import { useZocksStore } from '../../../app'
import { selectLocalParticipant } from '../../../store'
import { ChatMessageAttachment } from './ChatMessageAttachment'
import './ChatMessageWithParticipantInfo.scss'

const linkifyOptions = {
  defaultProtocol: 'https',
  target: '_blank',
}

interface InfoProps {
  showParticipantInfo: boolean
  localParticipantLabel?: string
}

export const ChatMessageWithParticipantInfo: React.FC<ChatMessageElementProps & InfoProps> = ({
  chatMessage,
  getAttachmentLocation,
  showParticipantInfo,
  localParticipantLabel = 'Me',
  chatMessageAttachmentElement,
}) => {
  const { id: localParticipantId } = useZocksStore(selectLocalParticipant)
  const {
    from: { id: senderId, name: senderName },
    to: { id: recipientId, name: recipientName } = {},
    message,
    attachment,
  } = chatMessage

  const sentByMe = senderId === localParticipantId
  const forMe = recipientId === localParticipantId
  const directMessage = !!recipientId

  const headerText =
    `${sentByMe ? localParticipantLabel : senderName}` +
    (directMessage ? ` To ${forMe ? localParticipantLabel : recipientName}` : '')

  const ChatMessageAttachmentElement = chatMessageAttachmentElement ?? ChatMessageAttachment

  return (
    <div
      className={classNames('chat-message-i__container', {
        'chat-message-i__container--sent': sentByMe,
        'chat-message-i__container--received': !sentByMe,
      })}
    >
      {showParticipantInfo && (
        <>
          <div className='chat-message-i__avatar'>{senderName.slice(0, 1)}</div>
          <div
            className={classNames('chat-message-i__header', {
              'chat-message-i__header--public': !directMessage,
              'chat-message-i__header--private': directMessage,
            })}
          >
            {headerText}
          </div>
        </>
      )}
      {message && (
        <Linkify options={linkifyOptions}>
          <div className='chat-message-i__message'>{message}</div>
        </Linkify>
      )}
      {attachment && getAttachmentLocation && (
        <ChatMessageAttachmentElement attachment={attachment} getAttachmentLocation={getAttachmentLocation} />
      )}
    </div>
  )
}

==> client-sdk-react-1.13.0.tgz: package/src/components/Chat/ChatMessage/ChatMessageWithParticipantInfo.tsx <==
import React from 'react'
import classNames from 'classnames'
import Linkify from 'linkify-react'
import { ChatMessageElementProps } from '../models'
import { useZocksStore } from '../../../app'
import { selectLocalParticipant } from '../../../store'
import { ChatMessageAttachment } from './ChatMessageAttachment'
import './ChatMessageWithParticipantInfo.scss'

const linkifyOptions = {
  defaultProtocol: 'https',
  target: '_blank',
}

interface InfoProps {
  showParticipantInfo: boolean
  localParticipantLabel?: string
}

export const ChatMessageWithParticipantInfo: React.FC<ChatMessageElementProps & InfoProps> = ({
  chatMessage,
  getAttachmentLocation,
  showParticipantInfo,
  localParticipantLabel = 'Me',
  chatMessageAttachmentElement,
}) => {
  const { id: localParticipantId } = useZocksStore(selectLocalParticipant)
  const {
    from: { id: senderId, name: senderName },
    to: { id: recipientId, name: recipientName } = {},
    message,
    attachment,
  } = chatMessage

  const sentByMe = senderId === localParticipantId
  const forMe = recipientId === localParticipantId
  const directMessage = !!recipientId

  const headerText =
    `${sentByMe ? localParticipantLabel : senderName}` +
    (directMessage ? ` To ${forMe ? localParticipantLabel : recipientName}` : '')

  const ChatMessageAttachmentElement = chatMessageAttachmentElement ?? ChatMessageAttachment

  return (
    <div
      className={classNames('chat-message-i__container', {
        'chat-message-i__container--sent': sentByMe,
        'chat-message-i__container--received': !sentByMe,
      })}
    >
      {showParticipantInfo && (
        <>
          <div className='chat-message-i__avatar' title={senderName}>{senderName.slice(0, 1)}</div>
          <div
            className={classNames('chat-message-i__header', {
              'chat-message-i__header--public': !directMessage,
              'chat-message-i__header--private': directMessage,
            })}
          >
            {headerText}
          </div>
        </>
      )}
      {message && (
        <Linkify options={linkifyOptions}>
          <div className='chat-message-i__message'>{message}</div>
        </Linkify>
      )}
      {attachment && getAttachmentLocation && (
        <ChatMessageAttachmentElement attachment={attachment} getAttachmentLocation={getAttachmentLocation} />
      )}
    </div>
  )
}
